# Changelog

## 1.1.1

- Support polylines with noncontiguous vertex arrays.


## 1.1.0

- Update polliwog and vg dependencies.


## 1.0.0

- Update polliwog and vg dependencies.


## 0.1.5

- Declare missing polliwog dependency.
- Update vg and lacecore dependencies.


## 0.1.4

- Update lacecore dependency.
- Note incompatibility with Python 3.9.


## 0.1.3

- Widen toolz dependency specifier.


## 0.1.2

- Fix issue where CSS colors are not applied correctly.


## 0.1.1

- Fix a crash when serializing certain meshes.
- Pin pycollada to 0.7.1.


## 0.1.0

Initial release.
